<?php
/**
	* If the block is dynamic you would render the template here.
	*/
$render = function ( $attributes, $content ) {
	$defaults = [
		'className' => false,
		'rowWidth' => false,
		'verticalAlign' => false,
		'minHeight' => false,
		'contrast' => false,

		'backgroundMediaUrl' => false,
		'backgroundSize' => false,

		'backgroundColor' => false,
		'backgroundOverlayColor' => false,
		'backgroundOverlayOpacity' => false,
	];

	// Add a filter to hook into the default args
	$defaults = apply_filters('gecko-blocks/section/defaults', $defaults, $attributes);
	$atts = wp_parse_args( $attributes, $defaults );

	$classNames = ['gecko-section'];
	if (isset($atts['className'])) {
		$classNames[] = $atts['className'];
	}

	if (isset($atts['rowWidth'])) {
		$classNames[] = 'is-row-width-' . $atts['rowWidth'];
	}

	if (isset($atts['verticalAlign'])) {
		$classNames[] = 'is-vertical-align-' . $atts['verticalAlign'];
	}

	if (isset($atts['contrast']) && $atts['contrast']) {
		$classNames[] = 'add-contrast';
	}

	// Add a filter to hook into classNames
	$classNames = apply_filters('gecko-blocks/section/class', $classNames, $attributes );

	$styles = [];
	if (isset($atts['backgroundColor'])) {
		$styles['background-color'] = $atts['backgroundColor'];
	}
	if (isset($atts['backgroundMediaUrl']) && $atts['backgroundMediaUrl'] != "") {
		$styles['background-image'] = "url('" . $atts['backgroundMediaUrl'] . "')";
	}
	if (isset($atts['backgroundMediaFocus']) && !empty($atts['backgroundMediaFocus'])) {
		$backgroundX = round($atts['backgroundMediaFocus']['x'] * 100);
		$backgroundY = round($atts['backgroundMediaFocus']['y'] * 100);
		$styles['background-position'] = $backgroundX.'% '.$backgroundY.'%';
	}
	if (isset($atts['minHeight']) && $atts['minHeight'] != "") {
		$styles['min-height'] = $atts['minHeight'];
	}
	if (isset($atts['backgroundSize']) && $atts['backgroundSize'] != "") {
		$styles['background-size'] = $atts['backgroundSize'];
	}
	// Add a filter to hook into the inine styles $args = ($styles, $atts)
	$styles = apply_filters('gecko-blocks/section/style', $styles, $attributes );

	$styleString = '';
	foreach ($styles as $key => $value) {
		if($value) $styleString .= $key.':'.$value.';';
	}

	$overlay = '';
	if (
		isset($atts['backgroundMediaUrl']) &&
		$atts['backgroundMediaUrl'] != "" &&
		isset($atts['backgroundOverlayOpacity']) &&
		$atts['backgroundOverlayOpacity'] >= 0 &&
		isset($atts['backgroundOverlayColor']) &&
		$atts['backgroundOverlayColor'] != ''
	) {
		$overlayStyle = [
			'background-color' => $atts['backgroundOverlayColor'],
			'opacity' => $atts['backgroundOverlayOpacity'] / 10,
		];
		$overlayStyleString = '';
		foreach ($overlayStyle as $key => $value) {
			if ($value) {
				$overlayStyleString .= $key . ':' . $value . ';';
			}
		}
		$overlay = '<div class="gecko-section__overlay" style="'.$overlayStyleString.'"></div>';
	}

	return sprintf('<div class="%s" style="%s">%s<div class="gecko-section__inner">%s</div></div>', implode(' ', $classNames), $styleString, $overlay, $content);
};